@@ -3,8 +3,8 @@
 #= Fortran 90/95 dependency lister
 #
 # Authors::   Yasuhiro MORIKAWA
-# Version::   $Id: f90depend.rb,v 1.1 2006/09/07 09:06:24 morikawa Exp $
-# Tag Name::  $Name: gt4f90io-20070616 $
+# Version::   $Id: f90depend.rb,v 1.2 2007/06/19 15:20:04 morikawa Exp $
+# Tag Name::  $Name: gt4f90io-20070620 $
 # Copyright:: Copyright (C) GFD Dennou Club, 2006. All rights reserved.
 # License::   See COPYRIGHT[link:../../COPYRIGHT]
 #
@@ -17,9 +17,10 @@ require "optparse"
 
 class Fortran90Dependency
 
-  def initialize(quiet=nil, strictly=nil)
+  def initialize(quiet=nil, verbose=nil, strictly=nil)
     @entries = []
     @quiet = quiet
+    @verbose = verbose
     @strictly = strictly
     @progress = $stderr unless quiet
   end
@@ -33,8 +34,16 @@ class Fortran90Dependency
     files.flatten!
     progress "  Adding     "
     files.each{|file|
-      progress "."
+      progress "\n    #{file}", '.'
       entry = Fortran90DependencyEntry.new(file, @strictly)
+      progress "\n      Modules: ", ''
+      entry.modules.each{ |m|
+        progress "\n        #{m}", ''
+      }
+      progress "\n      Uses: ", ''
+      entry.uses.each{ |u|
+        progress "\n        #{u}", ''
+      }
       @entries << entry if entry.modules
     }
     progress "\n"
@@ -51,7 +60,7 @@ class Fortran90Dependency
     files.each{|file|
       @entries.collect!{|entry|
         if File.expand_path(file) == File.expand_path(entry.file)
-          progress "."
+          progress "\n    #{file}", '.'
           next nil
         else
           next entry
@@ -88,8 +97,16 @@ class Fortran90Dependency
 
   private
 
-  def progress(char)
+  #
+  #  *char* Ϳ줿åɽ. 
+  # @quiet  true ξϲɽʤ. 
+  #  2  *clipto*  String 饹Ϳ, 
+  # @varbose  true ǤϤʤ, *char* Ϳ줿ʸ *clipto*
+  # ֤ޤ.
+  #
+  def progress(char, clipto=nil)
     unless @quiet
+      char = clipto if clipto && !(@verbose) && clipto.class.to_s == 'String'
       @progress.print(char)
       @progress.flush
     end
@@ -327,6 +344,10 @@ if $0 == __FILE__
                 "Progress message is not displayed"
                 ){|v| OPTS[:quiet] = v}
 
+    opt.on_tail('-v', '--verbose', 
+                "Verbose message is displayed"
+                ){|v| OPTS[:verbose] = v}
+
     opt.on_tail('-S', '--strict', 
                 "Fortran 90/95 files are strictly parsed.
                                      (But take a long time.)"
@@ -350,7 +371,7 @@ if $0 == __FILE__
     exit
   end
 
-  f90dep = Fortran90Dependency.new(OPTS[:quiet], OPTS[:strict])
+  f90dep = Fortran90Dependency.new(OPTS[:quiet], OPTS[:verbose], OPTS[:strict])
   f90dep.add_files(ARGV)
   f90dep.del_files(OPTS[:exclude].split(',')) if OPTS[:exclude]
   print f90dep.gen_list
